@@ -27,8 +27,11 @@ else:
     # backwards compatibility with Python35, Python36, and Python37
     from typing_extensions import Final
 
-# The type of results dicts
+
+# Type aliases
 ResultsDict = Dict[str, Dict[str, Any]]     #: Type of results dicts.
+ExperimentalParameters = Dict[str, Any]     #: Type of experimental parameter dicts.
+
 
 class Experiment(object):
     """Base class for an :term:`experiment` conducted in a :term:`lab`.
@@ -118,7 +121,7 @@ class Experiment(object):
 
     # ---------- Configuration ----------
 
-    def set(self, params: Dict[str, Any]) -> 'Experiment':
+    def set(self, params: ExperimentalParameters) -> 'Experiment':
         """Set the parameters for the experiment, returning the
         now-configured experiment.
 
@@ -129,7 +132,7 @@ class Experiment(object):
         self.configure(params)
         return self
 
-    def configure(self, params: Dict[str, Any]):
+    def configure(self, params: ExperimentalParameters):
         """Configure the experiment for the given parameters.
         The default stores the parameters for later use. Be sure
         to call this base method when overriding.
@@ -146,7 +149,7 @@ class Experiment(object):
 
     # ---------- Running the experiment ----------
 
-    def setUp(self, params: Dict[str, Any]):
+    def setUp(self, params: ExperimentalParameters):
         """Set up the experiment. Default does nothing.
 
         :param params: the parameters of the experiment"""
@@ -156,23 +159,23 @@ class Experiment(object):
         """Tear down the experiment. Default does nothing."""
         pass
 
-    def do(self, params: Dict[str, Any]) -> Union[Dict[str, Any], List[ResultsDict]]:
+    def do(self, params: ExperimentalParameters) -> Union[Dict[str, Any], List[ResultsDict]]:
         """Do the body of the experiment. This should be overridden by
         sub-classes. Default does nothing.
 
         An experiment can return two types of results:
 
-        - a dict mapping names to values for experimental results a
-        - list of :term:`results dict`s, which represent fully-formed
-          experiments
+        - a dict mapping names to values for experimental results; or
+        - a :term:`results dict` list, each of which represents a
+          fully-formed experiment
 
-        params: a dict of parameters for the experiment
-        returns: the experimental results
+        :param params: a dict of parameters for the experiment
+        :returns: the experimental results
 
         """
         return dict()
 
-    def report(self, params: Dict[str, Any], meta: Dict[str, Any], res: Union[Dict[str, Any], List[ResultsDict]]) -> ResultsDict:
+    def report(self, params: ExperimentalParameters, meta: Dict[str, Any], res: Union[Dict[str, Any], List[ResultsDict]]) -> ResultsDict:
         """Return a properly-structured dict of results. The default returns a
         dict with results keyed by :attr:`Experiment.RESULTS`, the
         data point in the parameter space keyed by
@@ -304,7 +307,7 @@ class Experiment(object):
         False if the experiment hasn't been run, or if it's been run
         and failed.
 
-        :returns: ``True`` if the experiment has been run successfully
+        :returns: True if the experiment has been run successfully
 
         """
         if self.STATUS in self.metadata().keys():
@@ -318,7 +321,7 @@ class Experiment(object):
         will be an exception and traceback information stored in the
         metadata. It will be False if the experiment hasn't been run.
 
-        :returns: ``True`` if the experiment has failed
+        :returns: True if the experiment has failed
 
         '''
         if self.STATUS not in self.metadata().keys():
